# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ..core.datetime_utils import serialize_datetime
from .prompt_execution_meta import PromptExecutionMeta
from .prompt_output import PromptOutput

try:
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore


class FulfilledExecutePromptResponse(pydantic.BaseModel):
    """
    The successful response from the model containing all of the resolved values generated by the prompt.
    """

    meta: typing.Optional[PromptExecutionMeta]
    raw: typing.Optional[typing.Dict[str, typing.Any]] = pydantic.Field(
        description="The subset of the raw response from the model that the request opted into with `expand_raw`."
    )
    execution_id: str = pydantic.Field(description="The ID of the execution.")
    outputs: typing.List[PromptOutput]

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        json_encoders = {dt.datetime: serialize_datetime}
